@@ -125,7 +125,7 @@ type TerraformCLI interface {
 	// so we need to switch the backend to local for temporary state operations.
 	// The filename argument must meet constraints for override file.
 	// (e.g.) _tfexec_override.tf
-	OverrideBackendToLocal(ctx context.Context, filename string, workspace string, isBackendTerraformCloud bool) (func(), error)
+	OverrideBackendToLocal(ctx context.Context, filename string, workspace string, isBackendTerraformCloud bool, backendConfig []string) (func(), error)
 
 	// PlanHasChange is a helper method which runs plan and return true if the plan has change.
 	PlanHasChange(ctx context.Context, state *State, opts ...string) (bool, error)
@@ -198,7 +198,7 @@ func (c *terraformCLI) SetExecPath(execPath string) {
 // The filename argument must meet constraints in order to override the file.
 // (e.g.) _tfexec_override.tf
 func (c *terraformCLI) OverrideBackendToLocal(ctx context.Context, filename string,
-	workspace string, isBackendTerraformCloud bool) (func(), error) {
+	workspace string, isBackendTerraformCloud bool, backendConfig []string) (func(), error) {
 	// create local backend override file.
 	path := filepath.Join(c.Dir(), filename)
 	contents := `
@@ -254,12 +254,15 @@ terraform {
 		}
 		log.Printf("[INFO] [executor@%s] switch back to remote\n", c.Dir())
 
+		var args = []string{"-input=false", "-no-color", "-reconfigure"}
+		for _, b := range backendConfig {
+			args = append(args, fmt.Sprintf("-backend-config=%s", b))
+		}
 		// Run the correct init command depending on whether the remote backend is Terraform Cloud
 		if !isBackendTerraformCloud {
-			err = c.Init(ctx, "-input=false", "-no-color", "-reconfigure")
-		} else {
-			err = c.Init(ctx, "-input=false", "-no-color")
+			args = append(args, "-reconfigure")
 		}
+		err = c.Init(ctx, args...)
 
 		if err != nil {
 			// we cannot return error here.
