@@ -257,7 +257,6 @@ terraform {
     force_path_style            = true
   }
 }
-
 # https://www.terraform.io/docs/providers/aws/index.html
 # https://www.terraform.io/docs/providers/aws/guides/custom-service-endpoints.html#localstack
 provider "aws" {
@@ -269,7 +268,7 @@ provider "aws" {
   skip_metadata_api_check     = true
   skip_region_validation      = true
   skip_requesting_account_id  = true
-  s3_force_path_style         = true
+  s3_use_path_style           = true
 
   // mock endpoints with localstack
   endpoints {
